# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0](https://github.com/RIVM-bioinformatics/biovalid/compare/biovalid-v0.1.0...biovalid-v0.2.0) (2025-08-27)


### Features

* first working version ([cb28d74](https://github.com/RIVM-bioinformatics/biovalid/commit/cb28d74e9d8ce4e7d61204eb4dc2e34b89de9c16))
* first working version ([7175758](https://github.com/RIVM-bioinformatics/biovalid/commit/71757585969b2e1337bc74f1d18061bb0768b577))


### Bug Fixes

* included windows line endings in fasta validator ([c676bb5](https://github.com/RIVM-bioinformatics/biovalid/commit/c676bb520544b3bf97031dd317cf275bccd9ebdf))
* move workflow to correct position ([3b5105b](https://github.com/RIVM-bioinformatics/biovalid/commit/3b5105b75d56ac7957441f887d7f63a670e75729))


### Documentation

* Update README.md ([ab20a40](https://github.com/RIVM-bioinformatics/biovalid/commit/ab20a401f3720f78fbbeba0c2e83eab512f62dad))


### CI/CD

* added tests into release-please workflow ([b52544c](https://github.com/RIVM-bioinformatics/biovalid/commit/b52544cc0b6fbc61c06f7197506f368ed8aa6f58))
* removed test pypi thing ([82fea19](https://github.com/RIVM-bioinformatics/biovalid/commit/82fea1961a51b8044482d48f15247d496b2382f6))
* update docstring e2e cli test ([136c239](https://github.com/RIVM-bioinformatics/biovalid/commit/136c23969e93ac10a62d6474971dcdb645df16e0))
* update docstring test_unit ([a1d4dba](https://github.com/RIVM-bioinformatics/biovalid/commit/a1d4dba2503a134874f7939f0edf020eacab93da))
* update docstring test_unit ([ab63e6b](https://github.com/RIVM-bioinformatics/biovalid/commit/ab63e6be18b529acc305a67045c37552ae36d7a0))

## [Unreleased]

### Added
- Initial release of biovalid package
- Validators for various genomic file formats (BAM, FASTA, FASTQ)
- Command-line interface for file validation
- Comprehensive test suite
